# -------------------------------------------------------------------------------------
# flo::plugin::Error
# -------------------------------------------------------------------------------------
#
#       Author : Jean-Michel Hiver (jhiver@mkdoc.com).
#    Copyright : (c) MKDoc Holdings Ltd, 2003
# 
#      Unauthorized modification, use, reuse, distribution or redistribution
#      of this module is stricly forbidden
#
#    Description:
#
#      This module is invoked when the query could not be processed, and returns
#      a 404 page
#
# -------------------------------------------------------------------------------------
package flo::plugin::Error;
use base qw /flo::Plugin/;
use strict;
use warnings;


sub activate
{
    1;
}


sub run
{
    my $self = shift;
    
    #    my $lang = $ENV{HTTP_ACCEPT_LANGUAGE};
    #    if (defined $lang and $lang)
    #    {
    #	$lang =~ s/^\s*//;
    #	$lang =~ s/,.*$//;
    #    }
    #    else
    #    {
    #	$lang = 'en';
    #    }
    
    my $status = $self->status();
    # my $code = $self->code();
    
    #my $template = new Petal
    #    file => "error/$code",
	#lang => $lang;
    
    # my $data = $template->process ( self => $self );
    # use bytes;
    
    print <<EOF;
Status: $status
Content-Type: text/plain

$@
EOF
    return 'TERMINATE';
}


sub status
{
    my $self = shift;
    my $status = $self->{status} || '404 Not Found';
    return $status;
}


sub code
{
    my $self = shift;
    my $status = $self->status();
    my ($code) = $status =~ /^(\d+)/;
    return $code;
}


1;
